@@ -54,6 +54,9 @@ impl std::convert::From<Error> for PyErr {
             Error::DeclaredTwice(s) => {
                 PyValueError::new_err(format!("{} has been declared twice!", s))
             }
+            Error::IllegalSequent(s) => {
+                PyValueError::new_err(format!("Illegal Sequent {}", s))
+            },
         }
     }
 }
